@@ -1,4 +1,3 @@
-use std::fs;
 use std::path::Path;
 
 use color_eyre::eyre::Result;
@@ -10,6 +9,7 @@ pub fn run() -> Result<()> {
     move_subdirs(&dirs::INSTALLS.join("golang"), &dirs::INSTALLS.join("go"))?;
     move_subdirs(&dirs::PLUGINS.join("nodejs"), &dirs::PLUGINS.join("node"))?;
     move_subdirs(&dirs::PLUGINS.join("golang"), &dirs::PLUGINS.join("go"))?;
+    move_trusted_configs()?;
 
     Ok(())
 }
@@ -24,7 +24,7 @@ fn move_subdirs(from: &Path, to: &Path) -> Result<()> {
             let to_file = to.join(&f);
             if !to_file.exists() {
                 debug!("moving {} to {}", from_file.display(), to_file.display());
-                fs::rename(from_file, to_file)?;
+                file::rename(from_file, to_file)?;
             }
         }
         file::remove_all(from)?;
@@ -32,3 +32,14 @@ fn move_subdirs(from: &Path, to: &Path) -> Result<()> {
 
     Ok(())
 }
+
+fn move_trusted_configs() -> Result<()> {
+    let from = dirs::CACHE.join("trusted-configs");
+    let to = dirs::CONFIG.join("trusted-configs");
+    if from.exists() && !to.exists() {
+        info!("migrating {} to {}", from.display(), to.display());
+        file::create_dir_all(to.parent().unwrap())?;
+        file::rename(from, to)?;
+    }
+    Ok(())
+}
