@@ -60,13 +60,13 @@ impl Shell for Nushell {
             $in | lines | parse "{{op}},{{name}},{{value}}"
           }}
             
-          def-env rtx [command?: string, --help, ...rest: string] {{
+          def --wrapped rtx [command?: string, --help, ...rest: string] {{
             let commands = ["shell", "deactivate"]
             
             if ($command == null) {{
               ^"{exe}"
             }} else if ($command == "activate") {{
-              let-env RTX_SHELL = "nu"
+              $env.RTX_SHELL = "nu"
             }} else if ($command in $commands) {{
               ^"{exe}" $command $rest
               | parse vars
