@@ -52,7 +52,7 @@ mod tests {
     fn test_tool_version_list() {
         let mut config = Config::default();
         let plugin_name = "tiny".to_string();
-        let plugin = ExternalPlugin::new(&plugin_name);
+        let plugin = ExternalPlugin::new(plugin_name.clone());
         let tool = Tool::new(plugin_name.clone(), Box::new(plugin));
         config.tools.insert(plugin_name.clone(), Arc::new(tool));
         let mut tvl = ToolVersionList::new(plugin_name.clone(), ToolSource::Argument);
@@ -70,7 +70,7 @@ mod tests {
         file::remove_all(dirs::CACHE.join("dummy")).unwrap();
         let mut config = Config::default();
         let plugin_name = "dummy".to_string();
-        let plugin = ExternalPlugin::new(&plugin_name);
+        let plugin = ExternalPlugin::new(plugin_name.clone());
         let tool = Tool::new(plugin_name.clone(), Box::new(plugin));
         config.tools.insert(plugin_name.clone(), Arc::new(tool));
         let mut tvl = ToolVersionList::new(plugin_name.clone(), ToolSource::Argument);
